@@ -1,7 +1,9 @@
 from pyfacebook.models import *
 from pyfacebook.ratelimit import RateLimitHeader, RateLimit, PercentSecond
 from pyfacebook.exceptions import PyFacebookException, FacebookError, LibraryError
-from pyfacebook.api import GraphAPI
+from pyfacebook.api import GraphAPI, BasicDisplayAPI
 from pyfacebook.api.facebook.client import FacebookApi
+from pyfacebook.api.instagram_business.client import IGBusinessApi
+from pyfacebook.api.instagram_basic.client import IGBasicDisplayApi
 
-__version__ = "0.10.0"
+__version__ = "0.11.2"
