@@ -21,7 +21,6 @@ logger = logging.getLogger(__name__)
 
 class GraphAPI:
     VALID_API_VERSIONS = [
-        "v3.3",
         "v4.0",
         "v5.0",
         "v6.0",
@@ -51,6 +50,7 @@ class GraphAPI:
         base_url: Optional[str] = None,
         timeout: Optional[int] = None,
         proxies: Optional[dict] = None,
+        instagram_business_id: Optional[str] = None,
     ):
         self.app_id = app_id
         self.app_secret = app_secret
@@ -62,6 +62,7 @@ class GraphAPI:
         self.sleep_on_rate_limit = sleep_on_rate_limit
         self.sleep_seconds_mapping = sleep_seconds_mapping
         self.rate_limit = RateLimit()
+        self.instagram_business_id = instagram_business_id
 
         # if provide url override
         self.base_url = self.GRAPH_URL
@@ -167,6 +168,7 @@ class GraphAPI:
         post_args: Optional[dict] = None,
         verb: str = "GET",
         auth_need: bool = True,
+        **kwargs,
     ) -> Response:
         """
         :param url: Resource url for Graph.
@@ -174,6 +176,7 @@ class GraphAPI:
         :param post_args: Form parameters.
         :param verb: HTTP method
         :param auth_need: Whether need access token.
+        :param kwargs: Additional parameters.
         :return:
         """
         if auth_need:
@@ -193,6 +196,7 @@ class GraphAPI:
                 params=args,
                 data=post_args,
                 proxies=self.proxies,
+                **kwargs,
             )
         except requests.HTTPError as ex:
             raise LibraryError({"message": ex.args})
@@ -236,6 +240,21 @@ class GraphAPI:
             error_data = data["error"]
             raise FacebookError(error_data)
 
+    def get(self, path, args):
+        """
+        Send GET request.
+
+        :param path: path for resource.
+        :param args: args for request.
+        :return: Response data
+        """
+        resp = self._request(
+            url=f"{self.version}/{path}",
+            args=args,
+        )
+        data = self._parse_response(resp)
+        return data
+
     def get_object(self, object_id: str, fields: str = "", **kwargs) -> dict:
         """
         Get object information by object id.
@@ -300,7 +319,7 @@ class GraphAPI:
         count: Optional[int] = 10,
         limit: Optional[int] = None,
         **kwargs,
-    ) -> Tuple[List[dict], Optional[dict]]:
+    ) -> dict:
         """
         Get connections objects for object by id. Like get page medias by page id.
 
@@ -310,14 +329,15 @@ class GraphAPI:
         :param limit: Each request retrieve objects count.
             For most connections should no more than 100. Default is None will use api default limit.
         :param kwargs: Additional parameters for different connections.
-        :return: Response data and latest paging info.
+        :return: Combined Response data
         """
 
-        if limit is not None:
-            kwargs["limit"] = limit
-
-        data_set, paging = [], None
+        data, data_set, paging = {}, [], None
         while True:
+            # sometimes may not return limit.
+            if limit is not None:
+                kwargs["limit"] = limit
+
             data = self.get_connection(
                 object_id=object_id,
                 connection=connection,
@@ -338,7 +358,61 @@ class GraphAPI:
             # parse next url args as new args
             kwargs = dict(parse_qsl(urlparse(_next).query))
 
-        return data_set, paging
+        # Replace the data list in data.
+        data["data"] = data_set
+        return data
+
+    def post_object(
+        self,
+        object_id: str,
+        connection: Optional[str] = None,
+        params: Optional[dict] = None,
+        data: Optional[dict] = None,
+        **kwargs,
+    ) -> dict:
+        """
+        Create or update data for a facebook object or it's edge.
+
+        :param object_id: ID for the facebook object(page,user.. and so on).
+        :param connection: Edge for the object.
+        :param params: Parameters for url path.
+        :param data: Parameters for Form data.
+        :param kwargs: Additional parameters.
+        :return: Response data.
+        """
+        path = f"{self.version}/{object_id}"
+        if connection:
+            path += f"/{connection}"
+
+        resp = self._request(
+            url=path,
+            args=params,
+            post_args=data,
+            verb="POST",
+            **kwargs,
+        )
+        data = self._parse_response(resp)
+        return data
+
+    def delete_object(
+        self,
+        object_id: str,
+        **kwargs,
+    ) -> dict:
+        """
+        Delete the facebook object.
+
+        :param object_id: ID for the facebook object(page,user..and so on)
+        :param kwargs: Additional parameters.
+        :return: Delete status.
+        """
+        resp = self._request(
+            url=f"{self.version}/{object_id}",
+            verb="DELETE",
+            **kwargs,
+        )
+        data = self._parse_response(resp)
+        return data
 
     def _get_oauth_session(
         self,
@@ -397,8 +471,8 @@ class GraphAPI:
         self, response: str, redirect_uri: Optional[str] = None
     ) -> dict:
         """
-        :param response: The redirect response url for
-        :param redirect_uri:
+        :param response: The redirect response url for authorize redirect
+        :param redirect_uri: Url for your redirect.
         :return:
         """
         session = self._get_oauth_session(redirect_uri=redirect_uri)
@@ -531,3 +605,119 @@ class GraphAPI:
         )
         data = self._parse_response(resp)
         return data
+
+
+class BasicDisplayAPI(GraphAPI):
+    GRAPH_URL = "https://graph.instagram.com/"
+    AUTHORIZATION_URL = "https://api.instagram.com/oauth/authorize"
+    EXCHANGE_ACCESS_TOKEN_URL = "https://api.instagram.com/oauth/access_token"
+
+    DEFAULT_SCOPE = ["user_profile", "user_media"]
+
+    def __init__(
+        self,
+        app_id: Optional[str] = None,
+        app_secret: Optional[str] = None,
+        access_token: Optional[str] = None,
+        oauth_flow: bool = False,
+        version: Optional[str] = None,
+        sleep_on_rate_limit: bool = True,
+        sleep_seconds_mapping: Optional[Dict[int, int]] = None,
+        timeout: Optional[int] = None,
+        proxies: Optional[dict] = None,
+    ):
+        super().__init__(
+            app_id=app_id,
+            app_secret=app_secret,
+            access_token=access_token,
+            oauth_flow=oauth_flow,
+            version=version,
+            sleep_on_rate_limit=sleep_on_rate_limit,
+            sleep_seconds_mapping=sleep_seconds_mapping,
+            timeout=timeout,
+            proxies=proxies,
+        )
+
+    @staticmethod
+    def _generate_secret_proof(
+        access_token: str, secret: Optional[str] = None
+    ) -> Optional[str]:
+        """
+        :param access_token: Access token
+        :param secret: App secret
+        :return:
+        """
+        return None
+
+    def exchange_user_access_token(
+        self, response: str, redirect_uri: Optional[str] = None
+    ) -> dict:
+        """
+        :param response: The redirect response url for authorize redirect
+        :param redirect_uri: Url for your redirect.
+        :return:
+        """
+        session = self._get_oauth_session(redirect_uri=redirect_uri)
+
+        session.fetch_token(
+            self.EXCHANGE_ACCESS_TOKEN_URL,
+            client_secret=self.app_secret,
+            authorization_response=response,
+            include_client_id=True,
+        )
+        self.access_token = session.access_token
+
+        return session.token
+
+    def exchange_long_lived_user_access_token(self, access_token=None) -> dict:
+        """
+        Exchange short-lived Instagram User Access Tokens for long-lived Instagram User Access Tokens.
+        :param access_token: short-lived user token.
+        :return: Long-lived user access token info.
+        """
+        if access_token is None:
+            access_token = self.access_token
+
+        args = {
+            "grant_type": "ig_exchange_token",
+            "client_secret": self.app_secret,
+            "access_token": access_token,
+        }
+        resp = self._request(
+            url=f"access_token",
+            args=args,
+            auth_need=False,
+        )
+        data = self._parse_response(resp)
+        return data
+
+    def refresh_access_token(self, access_token: str):
+        """
+        :param access_token: The valid (unexpired) long-lived Instagram User Access Token that you want to refresh.
+        :return: New access token.
+        """
+        args = {"grant_type": "ig_refresh_token", "access_token": access_token}
+        resp = self._request(
+            url="refresh_access_token",
+            args=args,
+        )
+        data = self._parse_response(resp)
+        return data
+
+    def exchange_page_access_token(
+        self, page_id: str, access_token: Optional[str] = None
+    ) -> str:
+        raise LibraryError({"message": "Method not support"})
+
+    def exchange_long_lived_page_access_token(
+        self, user_id: str, access_token: Optional[str] = None
+    ) -> dict:
+        raise LibraryError({"message": "Method not support"})
+
+    def get_app_token(
+        self, app_id: Optional[str] = None, app_secret: Optional[str] = None
+    ) -> dict:
+        raise LibraryError({"message": "Method not support"})
+
+    def debug_token(self, input_token: str, access_token: Optional[str] = None) -> dict:
+        raise LibraryError({"message": "Method not support"})
